pub struct UserShort {
pub id: String,
pub ingame_name: String,
pub avatar: Option<String>,
pub reputation: i16,
pub locale: String,
pub platform: String,
pub crossplay: bool,
pub status: String,
pub activity: Activity,
pub last_seen: String,
}Expand description
This is a shortened model of a user, which can be found in chats, messages, orders, bids, auctions, etc.
Fields
id: Stringingame_name: Stringavatar: Option<String>reputation: i16locale: Stringplatform: Stringcrossplay: boolstatus: Stringactivity: Activitylast_seen: StringTrait Implementations
Sourceimpl<'de> Deserialize<'de> for UserShort
impl<'de> Deserialize<'de> for UserShort
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more